| Copyright | Will Thompson, Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria (garetxe@gmail.com) |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Atk.Structs.PropertyValues
Description
Note: @old_value field of #AtkPropertyValues will not contain a valid value. This is a field defined with the purpose of contain the previous value of the property, but is not used anymore.
- newtype PropertyValues = PropertyValues (ForeignPtr PropertyValues)
- newZeroPropertyValues :: MonadIO m => m PropertyValues
- noPropertyValues :: Maybe PropertyValues
- propertyValuesReadNewValue :: PropertyValues -> IO GValue
- propertyValuesReadOldValue :: PropertyValues -> IO GValue
- propertyValuesReadPropertyName :: PropertyValues -> IO Text
Exported types
newtype PropertyValues Source
Constructors
| PropertyValues (ForeignPtr PropertyValues) |
Instances
| ((~) * info (ResolvePropertyValuesMethod t PropertyValues), MethodInfo * info PropertyValues p) => IsLabel t (PropertyValues -> p) Source | |
| ((~) * info (ResolvePropertyValuesMethod t PropertyValues), MethodInfo * info PropertyValues p) => IsLabelProxy t (PropertyValues -> p) Source | |
newZeroPropertyValues :: MonadIO m => m PropertyValues Source
Construct a PropertyValues struct initialized to zero.